pub struct TooManyWords {
pub remaining: usize,
}Expand description
Attempted to Decode an instance of a type from a slice containing more
Words than necessary.
Fields
remaining: usizeThe number of words left remaining in the slice.