Write

Trait Write 

pub trait Write {
    type Error: Debug + Display;

    // Required method
    fn write_word(&mut self, w: Word) -> Result<(), Self::Error>;
}
A trait for writing essential Words into buffers or streams.

Required Associated Types

type Error: Debug + Display

A type representing any error that might occur while writing words.

Required Methods

fn write_word(&mut self, w: Word) -> Result<(), Self::Error>

Write a single word into this writer, returning whether the write succeeded.

Implementations on Foreign Types

Source

impl Write for Vec<Word>

Source

type Error = Infallible

Source

fn write_word(&mut self, w: Word) -> Result<(), Self::Error>

Source

impl<W: Write> Write for &mut W

Source

type Error = <W as Write>::Error

Source

fn write_word(&mut self, w: Word) -> Result<(), Self::Error>

Implementors