Encoding, decoding and other helpers for working with the Pint Essential ABI.
Modules
Macros
- gen_
from_ file - Generate all items from an ABI JSON file at the given path.
- gen_
from_ str - Generate all items from a raw ABI JSON string.
Structs
- TooMany
Words - Attempted to
Decodean instance of a type from a slice containing moreWords than necessary.
Enums
- Decode
Error - Any error that might occur during a call to
decode. - From
Path Error - Errors that might occur when loading a
ContractABIorContractfrom a path.
Traits
- Decode
- A trait for decoding types from Essential
Words in a manner compatible with Pint’s ABI. - Encode
- A trait for encoding types as Essential
Words in a manner compatible with Pint’s ABI. - Read
- Allows for reading words from a source, largely inspired by
std::io::Read. - Write
- A trait for writing essential
Words into buffers or streams.
Functions
- contract_
from_ path - Shorthand for loading a
Contractfrom a given JSON file path. - decode
- Shorthand for decoding an instance of
Tfrom a slice of EssentialWords. - encode
- Shorthand for encoding the given value into a
Vecof EssentialWords. - find_
predicate - Given a
Contractand its associatedContractABI, find and return the predicate with the given name. - from_
path - Shorthand for loading the
ContractABIfrom a given ABI JSON file path.