pub trait Write {
type Error: Debug + Display;
// Required method
fn write_word(&mut self, w: Word) -> Result<(), Self::Error>;
}Expand description
A trait for writing essential Words into buffers or streams.
pub trait Write {
type Error: Debug + Display;
// Required method
fn write_word(&mut self, w: Word) -> Result<(), Self::Error>;
}A trait for writing essential Words into buffers or streams.